diy-django
==========

.. image:: http://img.shields.io/travis/collinanderson/diy-django.svg
   :target: http://travis-ci.org/collinanderson/diy-django
   :alt: travis

.. image:: http://img.shields.io/pypi/v/diy-django.svg
   :target: https://pypi.python.org/pypi/diy-django
   :alt: pypi version

.. image:: http://img.shields.io/pypi/l/diy-django.svg
   :target: https://pypi.python.org/pypi/diy-django
   :alt: pypi license

.. image:: https://readthedocs.org/projects/diy-django/badge/
   :target: http://diy-django.readthedocs.org/en/latest/
   :alt: documentation

http://diy-django.readthedocs.org

Features:

- Email as Username http://diy-django.readthedocs.org/en/latest/emailauth.html
- AJAX File Upload Widget with Progress http://diy-django.readthedocs.org/en/latest/ajaxupload.html
- Markdown http://diy-django.readthedocs.org/en/latest/markdown.html
